# Kannadafy/__init__.py

__version__ = "2.0.9"

from .core import (
    obfuscate,
    obfuscate_multiple,
    get_available_scripts, CHARACTER_SETS
)
from .kannadafy import (
    obfuscate_api,
    obfuscate_multiple_api
)
